pub struct ApplicationConfig {
pub(crate) watch_configuration: bool,
pub(crate) permit_debugging: bool,
pub(crate) allow_running_as_root: bool,
}Expand description
Structure to hold our application configuration options
Fields
watch_configuration: boolIf true, we should watch our configuration files for changes, and reload our configuration when they change.
Note that this feature may behave in unexpected ways if the path to the directory holding our configuration files changes its identity (because an intermediate symlink is changed, because the directory is removed and recreated, or for some other reason).
permit_debugging: boolIf true, we should allow other applications not owned by the system administrator to monitor the Arti application and inspect its memory.
Otherwise, we take various steps (including disabling core dumps) to make it harder for other programs to view our internal state.
This option has no effect when arti is built without the harden
feature. When harden is not enabled, debugger attachment is permitted
whether this option is set or not.
allow_running_as_root: boolIf true, then we do not exit when we are running as root.
This has no effect on Windows.
Implementations
Sourceimpl ApplicationConfig
impl ApplicationConfig
Sourcepub(crate) fn builder() -> ApplicationConfigBuilder
pub(crate) fn builder() -> ApplicationConfigBuilder
Return a new [ApplicationConfig Builder] to construct an instance of this type.