pub struct ArtiConfigBuilder {
application: ApplicationConfigBuilder,
proxy: ProxyConfigBuilder,
logging: LoggingConfigBuilder,
metrics: MetricsConfigBuilder,
rpc: RpcConfigBuilder,
system: SystemConfigBuilder,
storage: ArtiStorageConfigBuilder,
onion_services: OnionServiceProxyConfigMapBuilder,
}Expand description
A builder to create an instance of ArtiConfig.
Fields
application: ApplicationConfigBuilderIn-progress value for application.
proxy: ProxyConfigBuilderIn-progress value for proxy.
See ArtiConfig.proxy
logging: LoggingConfigBuilderIn-progress value for logging.
metrics: MetricsConfigBuilderIn-progress value for metrics.
rpc: RpcConfigBuilderIn-progress value for rpc.
See ArtiConfig.rpc
system: SystemConfigBuilderIn-progress value for system.
storage: ArtiStorageConfigBuilderIn-progress value for storage.
onion_services: OnionServiceProxyConfigMapBuilderIn-progress value for onion_services.
Implementations
Sourceimpl ArtiConfigBuilder
impl ArtiConfigBuilder
Sourcepub fn application(&mut self) -> &mut ApplicationConfigBuilder
pub fn application(&mut self) -> &mut ApplicationConfigBuilder
Return a mutable reference to the inner builder for application.
application
Configuration for application behavior.
Sourcepub fn proxy(&mut self) -> &mut ProxyConfigBuilder
pub fn proxy(&mut self) -> &mut ProxyConfigBuilder
Sourcepub fn logging(&mut self) -> &mut LoggingConfigBuilder
pub fn logging(&mut self) -> &mut LoggingConfigBuilder
Sourcepub fn metrics(&mut self) -> &mut MetricsConfigBuilder
pub fn metrics(&mut self) -> &mut MetricsConfigBuilder
Sourcepub fn rpc(&mut self) -> &mut RpcConfigBuilder
pub fn rpc(&mut self) -> &mut RpcConfigBuilder
Sourcepub fn system(&mut self) -> &mut SystemConfigBuilder
pub fn system(&mut self) -> &mut SystemConfigBuilder
Return a mutable reference to the inner builder for system.
system
Information on system resources used by Arti.
Note that there are other settings in this section,
in arti_client::config::SystemConfig -
these two structs overlay here.
Sourcepub fn storage(&mut self) -> &mut ArtiStorageConfigBuilder
pub fn storage(&mut self) -> &mut ArtiStorageConfigBuilder
Return a mutable reference to the inner builder for storage.
storage
Information on where things are stored by Arti.
Note that TorClientConfig also has a storage configuration;
our configuration logic should merge them correctly.
Sourceimpl ArtiConfigBuilder
impl ArtiConfigBuilder
Sourcepub fn build(&self) -> Result<ArtiConfig, ConfigBuildError>
pub fn build(&self) -> Result<ArtiConfig, ConfigBuildError>
Try to construct a new ArtiConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl ArtiConfigBuilder
impl ArtiConfigBuilder
Sourcefn post_build(config: ArtiConfig) -> Result<ArtiConfig, ConfigBuildError>
fn post_build(config: ArtiConfig) -> Result<ArtiConfig, ConfigBuildError>
validate the ArtiConfig after building.
Sourceimpl ArtiConfigBuilder
impl ArtiConfigBuilder
Sourcepub(crate) fn onion_services(
&mut self,
) -> &mut Vec<OnionServiceProxyConfigBuilder>
pub(crate) fn onion_services( &mut self, ) -> &mut Vec<OnionServiceProxyConfigBuilder>
Access the being-built list (resolving default)
If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.
Sourcepub(crate) fn set_onion_services(
&mut self,
list: Vec<OnionServiceProxyConfigBuilder>,
)
pub(crate) fn set_onion_services( &mut self, list: Vec<OnionServiceProxyConfigBuilder>, )
Set the whole list (overriding the default)
Sourcepub(crate) fn opt_onion_services(
&self,
) -> &Option<Vec<OnionServiceProxyConfigBuilder>>
pub(crate) fn opt_onion_services( &self, ) -> &Option<Vec<OnionServiceProxyConfigBuilder>>
Inspect the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &None is returned.
Sourcepub(crate) fn opt_onion_services_mut(
&mut self,
) -> &mut Option<Vec<OnionServiceProxyConfigBuilder>>
pub(crate) fn opt_onion_services_mut( &mut self, ) -> &mut Option<Vec<OnionServiceProxyConfigBuilder>>
Mutably access the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &mut None is returned.