pub struct RpcListenerSetConfig {
listener_options: ConnectPointOptionsBuilder,
file: Option<CfgPath>,
dir: Option<CfgPath>,
file_options: FileOptionsMapBuilder,
}Expand description
Configuration for a single source of connect points to use when configuring Arti as an RPC server.
This can configure either a connect point from a single toml file, or a set of connect points from a directory of toml files.
Fields
listener_options: ConnectPointOptionsBuilderAn builder to determine default connect point options.
If file is set, this builder is used directly
to determine the options for the connect points.
If dir is set, this builder defines a set of defaults
that we can override for each connect point in file_options.
file: Option<CfgPath>A path to a file on disk containing a connect string.
Exactly one of file or dir may be set.
dir: Option<CfgPath>A path to a directory on disk containing one or more connect strings.
Only files whose names end with ``.toml` are considered.
file_options: FileOptionsMapBuilderMap from file name within dir to builders for options on the individual files.
We hold builders here so that we can use ExtendBuilder to derive settings
using listener_options as the defaults.
Implementations
Sourceimpl RpcListenerSetConfig
impl RpcListenerSetConfig
Sourcepub(crate) fn builder() -> RpcListenerSetConfigBuilder
pub(crate) fn builder() -> RpcListenerSetConfigBuilder
Return a new [RpcListenerSetConfig Builder] to construct an instance of this type.
Sourceimpl RpcListenerSetConfig
impl RpcListenerSetConfig
Sourcepub(super) async fn bind<R: Runtime>(
&self,
runtime: &R,
config_key: &str,
resolver: &CfgPathResolver,
mistrust: &Mistrust,
) -> Result<Vec<(Listener, Arc<RpcConnInfo>, ListenerGuard)>>
pub(super) async fn bind<R: Runtime>( &self, runtime: &R, config_key: &str, resolver: &CfgPathResolver, mistrust: &Mistrust, ) -> Result<Vec<(Listener, Arc<RpcConnInfo>, ListenerGuard)>>
Load every enabled connect point from this file or directory, and bind to them.
On success, returns a list of bound sockets, along with information about how to treat incoming connections on those sockets, and a guard object that must not be dropped until we are no longer listening on the socket.