fn console_layer<S>(
config: &LoggingConfig,
cli: Option<&str>,
) -> Result<impl Layer<S> + use<S>>where
S: Subscriber + for<'span> LookupSpan<'span>,Expand description
Try to construct a tracing Layer for logging to stderr.
fn console_layer<S>(
config: &LoggingConfig,
cli: Option<&str>,
) -> Result<impl Layer<S> + use<S>>where
S: Subscriber + for<'span> LookupSpan<'span>,Try to construct a tracing Layer for logging to stderr.