pub fn setup_logging(
config: &LoggingConfig,
mistrust: &Mistrust,
path_resolver: &CfgPathResolver,
cli: Option<&str>,
) -> Result<LogGuards>Expand description
Set up logging.
Note that the returned LogGuard must be dropped precisely when the program quits; they’re used to ensure that all the log messages are flushed.