fn syslog_layer<S>(config: &LoggingConfig) -> Result<impl Layer<S>>where
S: Subscriber + for<'span> LookupSpan<'span>,Expand description
Try to construct a tracing Layer for logging to syslog, if one is
configured.
fn syslog_layer<S>(config: &LoggingConfig) -> Result<impl Layer<S>>where
S: Subscriber + for<'span> LookupSpan<'span>,Try to construct a tracing Layer for logging to syslog, if one is
configured.