pub struct LogfileListBuilder {
files: Option<Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>,
}Expand description
Builder for the Vec<LogfileConfig> type.
Wrapper struct to help derive_builder find the right types and methods
This struct is not part of the configuration API. Refer to the containing structures for information on how to build the config.
Fields
files: Option<Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>The list, as overridden
Implementations
Sourceimpl LogfileListBuilder
impl LogfileListBuilder
Sourcepub fn build(&self) -> Result<Vec<LogfileConfig>, ConfigBuildError>
pub fn build(&self) -> Result<Vec<LogfileConfig>, ConfigBuildError>
Resolve this list to a list of built items.
If the value is still the Default,
a built-in default list will be built and returned;
otherwise each applicable item will be built,
and the results collected into a single built list.
Sourcefn default_list() -> Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>
fn default_list() -> Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>
The default list
Sourcepub fn access(
&mut self,
) -> &mut Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>
pub fn access( &mut self, ) -> &mut Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>
Resolve the list to the default if necessary and then return &mut Vec
Sourcepub fn access_opt(
&self,
) -> &Option<Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
pub fn access_opt( &self, ) -> &Option<Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
Resolve the list to the default if necessary and then return &mut Vec
Sourcepub fn access_opt_mut(
&mut self,
) -> &mut Option<Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
pub fn access_opt_mut( &mut self, ) -> &mut Option<Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
Resolve the list to the default if necessary and then return &mut Vec