LoggingConfig

Struct LoggingConfig 

pub struct LoggingConfig {
    console: Option<String>,
    journald: Option<String>,
    syslog: Option<String>,
    opentelemetry: OpentelemetryConfig,
    tokio_console: TokioConsoleConfig,
    files: Vec<LogfileConfig>,
    log_sensitive_information: bool,
    protocol_warnings: bool,
    time_granularity: Duration,
}
Structure to hold our logging configuration options

Fields

console: Option<String>

Filtering directives that determine tracing levels as described at https://docs.rs/tracing-subscriber/latest/tracing_subscriber/filter/targets/struct.Targets.html#impl-FromStr

You can override this setting with the -l, –log-level command line parameter.

Example: “info,tor_proto::channel=trace”

journald: Option<String>

Filtering directives for the journald logger.

Only takes effect if Arti is built with the journald filter.

syslog: Option<String>

Filtering directives for the syslog logger.

Only takes effect if Arti is built with the syslog feature.

opentelemetry: OpentelemetryConfig

Configuration for logging spans with OpenTelemetry.

tokio_console: TokioConsoleConfig

Configuration for passing information to tokio-console.

files: Vec<LogfileConfig>

Configuration for one or more logfiles.

The default is not to log to any files.

log_sensitive_information: bool

If set to true, we disable safe logging on all logs, and store potentially sensitive information at level info or higher.

This can be useful for debugging, but it increases the value of your logs to an attacker. Do not turn this on in production unless you have a good log rotation mechanism.

protocol_warnings: bool

If set to true, promote Tor protocol-violation reports to warning level.

time_granularity: Duration

An approximate granularity with which log times should be displayed.

This value controls every log time that arti outputs; it doesn’t have any effect on times written by other logging programs like journald.

We may round this value up for convenience: For example, if you say “2.5s”, we may treat it as if you had said “3s.”

The default is “1s”, or one second.

Implementations

Source

impl LoggingConfig

pub(crate) fn builder() -> LoggingConfigBuilder

Return a new [LoggingConfig Builder] to construct an instance of this type.