pub struct OpentelemetryBatchConfigBuilder {
max_queue_size: Option<Option<usize>>,
max_export_batch_size: Option<Option<usize>>,
scheduled_delay: Option<Option<Duration>>,
}Expand description
A builder to create an instance of OpentelemetryBatchConfig.
Fields
max_queue_size: Option<Option<usize>>In-progress value for max_queue_size.
max_export_batch_size: Option<Option<usize>>In-progress value for max_export_batch_size.
scheduled_delay: Option<Option<Duration>>In-progress value for scheduled_delay.
Implementations
Sourceimpl OpentelemetryBatchConfigBuilder
impl OpentelemetryBatchConfigBuilder
Sourcepub fn max_queue_size(&mut self, val: impl PossiblyOption<usize>) -> &mut Self
pub fn max_queue_size(&mut self, val: impl PossiblyOption<usize>) -> &mut Self
Provide a value for max_queue_size.
If no value is provided for max_queue_size, build will use Default::default().
For convenience, this function accepts both usize and Option<$T>
.
max_queue_size
Maximum queue size. See opentelemetry_sdk::trace::BatchConfig::max_queue_size.
Sourcepub fn max_export_batch_size(
&mut self,
val: impl PossiblyOption<usize>,
) -> &mut Self
pub fn max_export_batch_size( &mut self, val: impl PossiblyOption<usize>, ) -> &mut Self
Provide a value for max_export_batch_size.
If no value is provided for max_export_batch_size, build will use Default::default().
For convenience, this function accepts both usize and Option<$T>
.
max_export_batch_size
Maximum export batch size. See opentelemetry_sdk::trace::BatchConfig::max_export_batch_size.
Sourcepub fn scheduled_delay(&mut self, val: Option<Duration>) -> &mut Self
pub fn scheduled_delay(&mut self, val: Option<Duration>) -> &mut Self
Provide a value for scheduled_delay.
If no value is provided for scheduled_delay, build will use Default::default().
scheduled_delay
Scheduled delay. See opentelemetry_sdk::trace::BatchConfig::scheduled_delay.
Sourceimpl OpentelemetryBatchConfigBuilder
impl OpentelemetryBatchConfigBuilder
Sourcepub fn build(&self) -> Result<OpentelemetryBatchConfig, ConfigBuildError>
pub fn build(&self) -> Result<OpentelemetryBatchConfig, ConfigBuildError>
Try to construct a new OpentelemetryBatchConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.