OnionServiceProxyConfigMapBuilder

Struct OnionServiceProxyConfigMapBuilder 

pub struct OnionServiceProxyConfigMapBuilder {
    services: Option<Vec<OnionServiceProxyConfigBuilder>>,
}
Wrapper struct to help derive_builder find the right types and methods

This struct is not part of the configuration API. Refer to the containing structures for information on how to build the config.

Fields

services: Option<Vec<OnionServiceProxyConfigBuilder>>

The list, as overridden

Implementations

Source

impl OnionServiceProxyConfigMapBuilder

pub(crate) fn build( &self, ) -> Result<BTreeMap<HsNickname, OnionServiceProxyConfig>, ConfigBuildError>

Resolve this list to a list of built items.

If the value is still the Default, a built-in default list will be built and returned; otherwise each applicable item will be built, and the results collected into a single built list.

fn default_list() -> Vec<OnionServiceProxyConfigBuilder>

The default list

pub(crate) fn access(&mut self) -> &mut Vec<OnionServiceProxyConfigBuilder>

Resolve the list to the default if necessary and then return &mut Vec

pub(crate) fn access_opt(&self) -> &Option<Vec<OnionServiceProxyConfigBuilder>>

Resolve the list to the default if necessary and then return &mut Vec

pub(crate) fn access_opt_mut( &mut self, ) -> &mut Option<Vec<OnionServiceProxyConfigBuilder>>

Resolve the list to the default if necessary and then return &mut Vec