enable_process_hardening

Function enable_process_hardening 

pub fn enable_process_hardening() -> Result<()>
Enable process hardening, to make it harder for low-privilege users to extract information from Arti.

This function only has effect the first time it is called. If it returns an error, the caller should probably exit the process.

Limitations

See notes from the secmem_proc crate: this is a best-effort defense, and only makes these attacks harder. It can interfere with debugging.