classify_protocol_from_first_byte

Function classify_protocol_from_first_byte 

fn classify_protocol_from_first_byte(byte: u8) -> Option<ProxyProtocols>
Look at the first byte of a proxy connection, and guess what protocol what protocol it is trying to speak.