fn extract_proto_err<'a>(error: &'a (dyn Error + 'static)) -> Option<&'a Error>Expand description
If any source of the provided error is a tor_proto::Error, return a reference to that
tor_proto::Error.
fn extract_proto_err<'a>(error: &'a (dyn Error + 'static)) -> Option<&'a Error>If any source of the provided error is a tor_proto::Error, return a reference to that
tor_proto::Error.