handle_proxy_conn

Function handle_proxy_conn 

async fn handle_proxy_conn<R, S>(
    context: ProxyContext<R>,
    stream: S,
    isolation_info: (usize, IpAddr),
) -> Result<()>
where R: Runtime, S: AsyncRead + AsyncWrite + Send + Sync + Unpin + 'static,
Handle a single connection stream from an application.

Depending on what protocol the application is speaking (and what protocols we support!), negotiate an appropriate set of options, and relay traffic to and from the application.