enum HttpConnectError {
InvalidStreamTarget(Sensitive<String>, TorAddrError),
DuplicateHeader,
HeaderNotUtf8,
InvalidFamilyPreference,
NoRpcSupport,
RpcObjectNotFound,
ConnectFailed(Sensitive<TorAddr>, Box<dyn ClientConnectionError>),
Internal(Bug),
}Expand description
An error that occurs during an HTTP CONNECT attempt, which can (usually) be reported to the client.
Variants
InvalidStreamTarget(Sensitive<String>, TorAddrError)
Tried to connect to an invalid stream target.
DuplicateHeader
We found a duplicate HTTP header that we do not allow.
(We only enforce this for the headers that we look at ourselves.)
HeaderNotUtf8
We tried to found an HTTP header whose value wasn’t encode as UTF-8.
(We only enforce this for the headers that we look at ourselves.)
InvalidFamilyPreference
The Tor-Family-Preference header wasn’t as expected.
NoRpcSupport
The user asked to use an RPC object, but we don’t support RPC.
RpcObjectNotFound
The user asked to use an RPC object, but we didn’t find the one they wanted.
ConnectFailed(Sensitive<TorAddr>, Box<dyn ClientConnectionError>)
arti_client was unable to connect to a stream target.
Internal(Bug)
We encountered an internal error.
Implementations
Sourceimpl HttpConnectError
impl HttpConnectError
Sourcefn status_code(&self) -> StatusCode
fn status_code(&self) -> StatusCode
Return an appropriate HTTP status code for this error.
Sourcefn try_into_response(self) -> Result<Response<String>, HttpConnectError>
fn try_into_response(self) -> Result<Response<String>, HttpConnectError>
If possible, return a response that we should give to this error.
Sourcefn remote_end_reason(&self) -> Option<EndReason>
fn remote_end_reason(&self) -> Option<EndReason>
Return the end reason for this error, if this error does in fact represent an END message from the remote side of a stream.