fn find_conn_target<R: Runtime>(
context: &ProxyContext<R>,
rpc_target: Option<&str>,
) -> Result<ConnTarget<R>, HttpConnectError>Expand description
Look up the connection target given the value of an Tor-RPC-Target header.
fn find_conn_target<R: Runtime>(
context: &ProxyContext<R>,
rpc_target: Option<&str>,
) -> Result<ConnTarget<R>, HttpConnectError>Look up the connection target given the value of an Tor-RPC-Target header.