handle_connect_request_impl

Function handle_connect_request_impl 

async fn handle_connect_request_impl<R, S>(
    request: Request<Incoming>,
    context: &ProxyContext<R>,
    listener_isolation: (usize, IpAddr),
) -> Result<Response<String>, HttpConnectError>
where R: Runtime, S: AsyncRead + AsyncWrite + Send + Sync + Unpin + 'static,
Helper for handle_connect_request: return an error type that can be converted into an HTTP message.

(This is a separate function to make error handling simpler.)