transfer

Function transfer 

async fn transfer<S>(
    request: Request<Incoming>,
    tor_stream: DataStream,
) -> Result<()>
where S: AsyncRead + AsyncWrite + Send + Sync + Unpin + 'static,
Recover the application stream from request, and launch tasks to transfer data between the application and the tor_stream.