fn serialize_address<S: Serializer>(
addr: &SocketAddr,
ser: S,
) -> Result<S::Ok, S::Error>Expand description
Helper: serialize a general::SocketAddr as a string if possible, or as None if it can’t be represented as a string.
fn serialize_address<S: Serializer>(
addr: &SocketAddr,
ser: S,
) -> Result<S::Ok, S::Error>Helper: serialize a general::SocketAddr as a string if possible, or as None if it can’t be represented as a string.