pub fn stream_preference(req: &SocksRequest, addr: &str) -> StreamPrefsExpand description
Find out which kind of address family we can/should use for a
given SocksRequest.
pub fn stream_preference(req: &SocksRequest, addr: &str) -> StreamPrefsFind out which kind of address family we can/should use for a
given SocksRequest.