pub struct CfgMgr<R> {
runtime: R,
sources: ConfigurationSources,
tx: FileEventSender,
inner: Mutex<CfgMgrInner>,
}Expand description
Structure to reload configuration as necessary.
Fields
runtime: RA runtime that we use when constructing FileWatchers.
sources: ConfigurationSourcesThe sources from which we read our configuration.
tx: FileEventSenderA sender to use when constructing new FileWatchers.
inner: Mutex<CfgMgrInner>Mutable state.
Implementations
Sourceimpl<R: Runtime> CfgMgr<R>
impl<R: Runtime> CfgMgr<R>
Sourcepub fn new(
runtime: R,
sources: ConfigurationSources,
loaded_cfg: ConfigurationTree,
config: &ArtiConfig,
modules: Vec<Weak<dyn ReconfigurableModule>>,
) -> Result<(Arc<Self>, UnlaunchedWatcher<R>)>
pub fn new( runtime: R, sources: ConfigurationSources, loaded_cfg: ConfigurationTree, config: &ArtiConfig, modules: Vec<Weak<dyn ReconfigurableModule>>, ) -> Result<(Arc<Self>, UnlaunchedWatcher<R>)>
Construct a new CfgMgr, and launch a task to watch for any events that mean we have to reload our configuration.
If the provided configuration requires it, watch for changes in sources
and try to reload our configuration. On unix platforms, also watch
for SIGHUP and reload configuration then.
The modules are Weak references to prevent this background task
from keeping them alive.
See the FileWatcher docs for limitations.
Sourcefn launch_file_watcher(&self) -> Result<(FileWatcher, FoundConfigFiles<'_>)>
fn launch_file_watcher(&self) -> Result<(FileWatcher, FoundConfigFiles<'_>)>
Create a new FileWatcher for the files in this configuration.
Return it, along with the set of files we found.
The caller is responsible for storing the FileWatcher; when it is dropped,
it stops watching.
Sourcepub fn reload_configuration(&self, how: Reconfigure) -> Result<()>
pub fn reload_configuration(&self, how: Reconfigure) -> Result<()>
Reload the configuration.
Sourcepub fn try_modify_cfg<F>(
&self,
func: F,
how: Reconfigure,
) -> Result<(), ChangeConfigurationError>
pub fn try_modify_cfg<F>( &self, func: F, how: Reconfigure, ) -> Result<(), ChangeConfigurationError>
Try to change the set of RPC configuration options.
On success, the configuration is changed, and the changes are applied.
On failure, the configuration is not changed, and the changes are not applied.
Sourcepub(crate) fn get_cfg_setting(
&self,
key: &str,
) -> Result<Option<ConfigValue>, ConfigGetValueError>
pub(crate) fn get_cfg_setting( &self, key: &str, ) -> Result<Option<ConfigValue>, ConfigGetValueError>
Return the configuration value for a given key, if any is set.