struct CfgMgrInner {
modules: Vec<Weak<dyn ReconfigurableModule>>,
watcher: Option<FileWatcher>,
loaded_cfg: ConfigurationTree,
additional_cfg: ConfigSettings,
normalized_cfg: ConfigurationTree,
unrecognized_keys: HashSet<DisfavouredKey>,
deprecated_keys: HashSet<DisfavouredKey>,
}Expand description
Mutable part of a CfgMgr.
RPC Dataflow
We keep a fair amount of state for our configuration, especially when we are supporting RPC. A few important pieces are, in dataflow order:
sources: A set ofConfigurationSourcestelling us where to load our configuration from.loaded_cfg: AConfigurationTreethat we have loaded from oursources. This is the most recent tree that we were able to successfully decode and apply. (RPC only)additional_cfg: A set ofrpc::ConfigSettingsprovided by an RPC superuser app, to override options inloaded_cfg. (RPC only)normalized_cfg: AConfigurationTreeproduced by combining loaded_cfgandadditional_cfg`, and filling any missing defaults.
When we are reloading our configuration from disk, we use sources to
load and parse a new ConfigurationTree, then we apply additional_cfg to it,
and then we see whether that configuration can successfully be resolved
and used to reconfigure the modules in Arti.
On success, we replace loaded_cfg and normalized_cfg,
When we are changing our configuration via RPC, we try to change additional_cfg,
apply it to loaded_cfg,
and then we see whether that configuration can successfully be resolved
and used to reconfigure the modules in Arti.
On success, we replace normalized_cfg and additional_cfg.
Fields
modules: Vec<Weak<dyn ReconfigurableModule>>A list of modules to alert whenever the configuration has changed.
watcher: Option<FileWatcher>If present, a FileWatcher that is currently watching for changes
in the configuration files and directories.
loaded_cfg: ConfigurationTreeRPC only: The most recent configuration tree as loaded. We use this to apply additional_cfg repeatedly without reloading all the files every time RPC tells us to change something.
additional_cfg: ConfigSettingsRPC only: A set of RPC-provided options to apply to the configuration before decoding it.
normalized_cfg: ConfigurationTreeRPC only: a fully populated, normalized configuration tree, based on the most recent time
that we called CfgMgr::reload_configuration.
unrecognized_keys: HashSet<DisfavouredKey>RPC only: a set of unrecognized options from the configuration.
deprecated_keys: HashSet<DisfavouredKey>RPC only: a set of deprecated options from the configuration