pub struct ConnectPointOptionsBuilder {
enable: Option<bool>,
}Expand description
A builder to create an instance of ConnectPointOptions.
Fields
enable: Option<bool>In-progress value for enable.
Implementations
Sourceimpl ConnectPointOptionsBuilder
impl ConnectPointOptionsBuilder
Sourcepub fn build(&self) -> Result<ConnectPointOptions, ConfigBuildError>
pub fn build(&self) -> Result<ConnectPointOptions, ConfigBuildError>
Try to construct a new ConnectPointOptions from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl ConnectPointOptionsBuilder
impl ConnectPointOptionsBuilder
Sourcefn is_enabled(&self) -> bool
fn is_enabled(&self) -> bool
Return true if this builder represents an enabled connect point.
Sourcefn load_options(&self) -> LoadOptions
fn load_options(&self) -> LoadOptions
Return a LoadOptions corresponding to this OverrideConfig.
The LoadOptions will contain a subset of our own options,
set in order to make ParsedConnectPoint::load_dir behaved as configured here.