pub struct RpcListenerSetConfigBuilder {
listener_options: ConnectPointOptionsBuilder,
file: Option<Option<CfgPath>>,
dir: Option<Option<CfgPath>>,
file_options: FileOptionsMapBuilder,
}Expand description
A builder to create an instance of RpcListenerSetConfig.
Fields
listener_options: ConnectPointOptionsBuilderIn-progress value for listener_options.
file: Option<Option<CfgPath>>In-progress value for file.
dir: Option<Option<CfgPath>>In-progress value for dir.
file_options: FileOptionsMapBuilderIn-progress value for file_options.
Implementations
Sourceimpl RpcListenerSetConfigBuilder
impl RpcListenerSetConfigBuilder
Sourceimpl RpcListenerSetConfigBuilder
impl RpcListenerSetConfigBuilder
Sourcepub fn build(&self) -> Result<RpcListenerSetConfig, ConfigBuildError>
pub fn build(&self) -> Result<RpcListenerSetConfig, ConfigBuildError>
Try to construct a new RpcListenerSetConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl RpcListenerSetConfigBuilder
impl RpcListenerSetConfigBuilder
Sourcefn validate(&self) -> Result<(), ConfigBuildError>
fn validate(&self) -> Result<(), ConfigBuildError>
Return an error if this builder isn’t valid.
Sourcepub fn listener_options(&mut self) -> &mut ConnectPointOptionsBuilder
pub fn listener_options(&mut self) -> &mut ConnectPointOptionsBuilder
Return a mutable reference to the listener options.
This field determines the default connect point options.
If file is set, this builder is used directly
to determine the options for the connect points.
If dir is set, this builder defines a set of defaults
that we can override for each connect point in file_options.
Sourcepub fn file_options(&mut self) -> &mut FileOptionsMapBuilder
pub fn file_options(&mut self) -> &mut FileOptionsMapBuilder
Return a mutable reference to the file options
This field is a map from file name within dir to builders for options on the individual files.
We hold builders here so that we can use ExtendBuilder to derive settings
using listener_options as the defaults.