pub(super) struct ArtiRpcSession {
pub(super) arti_state: Arc<RpcVisibleArtiState>,
session: Arc<RpcSession>,
}Expand description
A top-level RPC session object.
This is the first object that an RPC user receives upon authenticating;
It is returned by auth:authenticate.
Other objects (TorClient,RpcDataStream, etc)
are available using methods on this object.
(See the list of available methods.)
This type wraps and delegates to arti_rpcserver::RpcSession,
but exposes additional functionality not available at the
level of arti_rpcserver, including information about configured proxies.
This ObjectID for this object can be used as the target of a SOCKS stream.
Fields
arti_state: Arc<RpcVisibleArtiState>State about the arti server, as seen by the Rpc system.
session: Arc<RpcSession>The underlying RpcSession object that we delegate to.
Implementations
Sourceimpl ArtiRpcSession
impl ArtiRpcSession
Sourcepub(super) fn new<R: Runtime>(
auth: &RpcAuthentication,
client_root: &TorClient<R>,
arti_state: &Arc<RpcVisibleArtiState>,
listener_info: &RpcConnInfo,
) -> Arc<Self>
pub(super) fn new<R: Runtime>( auth: &RpcAuthentication, client_root: &TorClient<R>, arti_state: &Arc<RpcVisibleArtiState>, listener_info: &RpcConnInfo, ) -> Arc<Self>
Construct a new ArtiRpcSession.
Privileges on the session (if any) are derived from auth, which describes
how the user authenticated.
The session receives a new isolated TorClient, based on client_root.