pub struct RpcConfigBuilder {
enable: Option<bool>,
listen: RpcConfigListenMapBuilder,
listen_default: RpcConfigListenDefaultListBuilder,
}Expand description
A builder to create an instance of RpcConfig.
Fields
enable: Option<bool>In-progress value for enable.
See RpcConfig.enable
listen: RpcConfigListenMapBuilderIn-progress value for listen.
See RpcConfig.listen
listen_default: RpcConfigListenDefaultListBuilderIn-progress value for listen_default.
Implementations
Sourceimpl RpcConfigBuilder
impl RpcConfigBuilder
Sourceimpl RpcConfigBuilder
impl RpcConfigBuilder
Sourcepub fn listen_default(&mut self) -> &mut Vec<String>
pub fn listen_default(&mut self) -> &mut Vec<String>
Access the being-built list (resolving default)
If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.
Sourcepub fn set_listen_default(&mut self, list: Vec<String>)
pub fn set_listen_default(&mut self, list: Vec<String>)
Set the whole list (overriding the default)
Sourcepub fn opt_listen_default(&self) -> &Option<Vec<String>>
pub fn opt_listen_default(&self) -> &Option<Vec<String>>
Inspect the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &None is returned.
Sourcepub fn opt_listen_default_mut(&mut self) -> &mut Option<Vec<String>>
pub fn opt_listen_default_mut(&mut self) -> &mut Option<Vec<String>>
Mutably access the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &mut None is returned.