EnterDormantMode

Struct EnterDormantMode 

struct EnterDormantMode {}
Enter “dormant mode”.

Currently, the only available dormant mode is “soft dormant mode”, which suspends most background operations until any client request is received.

Since this method affects all applications using the Arti process, it requires administrative permissions.

Limitations

As of 2026 March, this functionality is not perfectly implemented, and likely does not interact well with onion services. Additionally, there are likely background operations that this operation doesn’t cover.

This method returns a reply immediately, but it may take a little while before all of the background tasks finish their work and stop.