fn display_service_discovery_key(
args: &KeygenArgs,
key: &HsClientDescEncKey,
) -> Result<()>Expand description
Display the public part of a service discovery key.
fn display_service_discovery_key(
args: &KeygenArgs,
key: &HsClientDescEncKey,
) -> Result<()>Display the public part of a service discovery key.