fn build_prompt(entries: &Vec<KeystoreEntry<'_>>) -> StringExpand description
Helper function for migrate_ctor_keys.
Builds a prompt that will be passed to the prompt function.
fn build_prompt(entries: &Vec<KeystoreEntry<'_>>) -> StringHelper function for migrate_ctor_keys.
Builds a prompt that will be passed to the prompt function.