find_ctor_keystore

Function find_ctor_keystore 

fn find_ctor_keystore(
    client_config: &TorClientConfig,
    args: &CommonArgs,
) -> Result<KeystoreId>
Checks if the service identified by the HsNickname provided by the user is configured with any of the recognized CTor keystores.

Returns different errors messages to indicate specific failure conditions if the procedure cannot continue, Ok(()) otherwise.