migrate_ctor_keys

Function migrate_ctor_keys 

fn migrate_ctor_keys(
    migrate_args: &CTorMigrateArgs,
    args: &CommonArgs,
    client: &InertTorClient,
    ctor_keystore_id: &KeystoreId,
) -> Result<()>
Migrate the keys of the specified C Tor service to the Arti keystore.

Performs key migration for the service identified by the HsNickname provided via --nickname, copying keys from the CTor keystore configured for the service to the default Arti native keystore.

If the service with the specified nickname had some keys in the Arti keystore prior to the migration, those keys will be removed.

If args.batch is false, the user will be prompted for the deletion of the existing entries from the original Arti keystore.