pub(crate) enum KeysSubcommand {
List(ListArgs),
ListKeystores,
CheckIntegrity(CheckIntegrityArgs),
}Expand description
The keys subcommand.
Variants
List(ListArgs)
List keys and certificates.
Note: The output fields “Location” and “Keystore ID” represent,
respectively, the raw identifier of an entry (e.g. <ARTI_PATH>.<ENTRY_TYPE>
for ArtiNativeKeystore), and the identifier of the keystore that
contains the entry.
ListKeystores
List keystores.
CheckIntegrity(CheckIntegrityArgs)
Validate the integrity of keystores.
Detects and reports unrecognized entries and paths, as well as malformed or expired keys.
Such entries will be removed if this command is invoked with --sweep.