print_check_integrity_incipit

Function print_check_integrity_incipit 

fn print_check_integrity_incipit(
    affected_keystores: &[InvalidKeystoreEntries<'_>],
)
Helper function for display_invalid_keystore_entries that reduces cognitive complexity.

Produces and displays the opening section of the final output, given a list of keystores containing invalid entries and their IDs. This function does not check whether affected_keystores or the inner collections are empty.