pub struct LoggingConfigBuilder {
console: Option<Option<String>>,
journald: Option<Option<String>>,
syslog: Option<Option<String>>,
opentelemetry: OpentelemetryConfigBuilder,
tokio_console: TokioConsoleConfigBuilder,
files: LogfileListBuilder,
log_sensitive_information: Option<bool>,
protocol_warnings: Option<bool>,
time_granularity: Option<Duration>,
}Expand description
A builder to create an instance of LoggingConfig.
Fields
console: Option<Option<String>>In-progress value for console.
journald: Option<Option<String>>In-progress value for journald.
syslog: Option<Option<String>>In-progress value for syslog.
opentelemetry: OpentelemetryConfigBuilderIn-progress value for opentelemetry.
tokio_console: TokioConsoleConfigBuilderIn-progress value for tokio_console.
files: LogfileListBuilderIn-progress value for files.
log_sensitive_information: Option<bool>In-progress value for log_sensitive_information.
protocol_warnings: Option<bool>In-progress value for protocol_warnings.
time_granularity: Option<Duration>In-progress value for time_granularity.
Implementations
Sourceimpl LoggingConfigBuilder
impl LoggingConfigBuilder
Sourcepub fn console(&mut self, val: impl OptionStringOrStr) -> &mut Self
pub fn console(&mut self, val: impl OptionStringOrStr) -> &mut Self
Provide a value for console.
If no value is provided for console, build will use Default::default().
For convenience, this function accepts String, &str, Option<String>, and Option<&str>.
console
Filtering directives that determine tracing levels as described at https://docs.rs/tracing-subscriber/latest/tracing_subscriber/filter/targets/struct.Targets.html#impl-FromStr
You can override this setting with the -l, –log-level command line parameter.
Example: “info,tor_proto::channel=trace”
Sourcepub fn journald(&mut self, val: impl OptionStringOrStr) -> &mut Self
pub fn journald(&mut self, val: impl OptionStringOrStr) -> &mut Self
Provide a value for journald.
For convenience, this function accepts String, &str, Option<String>, and Option<&str>.
journald
Filtering directives for the journald logger.
Only takes effect if Arti is built with the journald filter.
Sourcepub fn syslog(&mut self, val: impl OptionStringOrStr) -> &mut Self
pub fn syslog(&mut self, val: impl OptionStringOrStr) -> &mut Self
Sourcepub fn opentelemetry(&mut self) -> &mut OpentelemetryConfigBuilder
pub fn opentelemetry(&mut self) -> &mut OpentelemetryConfigBuilder
Return a mutable reference to the inner builder for opentelemetry.
opentelemetry
Configuration for logging spans with OpenTelemetry.
Sourcepub fn tokio_console(&mut self) -> &mut TokioConsoleConfigBuilder
pub fn tokio_console(&mut self) -> &mut TokioConsoleConfigBuilder
Return a mutable reference to the inner builder for tokio_console.
tokio_console
Configuration for passing information to tokio-console.
Sourcepub fn log_sensitive_information(&mut self, val: bool) -> &mut Self
pub fn log_sensitive_information(&mut self, val: bool) -> &mut Self
Provide a value for log_sensitive_information.
If no value is provided for log_sensitive_information, build will use Default::default().
log_sensitive_information
If set to true, we disable safe logging on all logs, and store
potentially sensitive information at level info or higher.
This can be useful for debugging, but it increases the value of your logs to an attacker. Do not turn this on in production unless you have a good log rotation mechanism.
Sourcepub fn protocol_warnings(&mut self, val: bool) -> &mut Self
pub fn protocol_warnings(&mut self, val: bool) -> &mut Self
Sourcepub fn time_granularity(&mut self, val: Duration) -> &mut Self
pub fn time_granularity(&mut self, val: Duration) -> &mut Self
Provide a value for time_granularity.
If no value is provided for time_granularity, build will use Default::default().
time_granularity
An approximate granularity with which log times should be displayed.
This value controls every log time that arti outputs; it doesn’t have any
effect on times written by other logging programs like journald.
We may round this value up for convenience: For example, if you say “2.5s”, we may treat it as if you had said “3s.”
The default is “1s”, or one second.
Sourceimpl LoggingConfigBuilder
impl LoggingConfigBuilder
Sourcepub fn files(
&mut self,
) -> &mut Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>
pub fn files( &mut self, ) -> &mut Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>
Access the being-built list (resolving default)
If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.
Sourcepub fn set_files(
&mut self,
list: Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>,
)
pub fn set_files( &mut self, list: Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>, )
Set the whole list (overriding the default)
Sourcepub fn opt_files(
&self,
) -> &Option<Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
pub fn opt_files( &self, ) -> &Option<Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
Inspect the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &None is returned.
Sourcepub fn opt_files_mut(
&mut self,
) -> &mut Option<Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
pub fn opt_files_mut( &mut self, ) -> &mut Option<Vec<<<Vec<LogfileConfig> as ShouldUseListBuilder>::Element as BuildableTrait>::Builder>>
Mutably access the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &mut None is returned.
Sourceimpl LoggingConfigBuilder
impl LoggingConfigBuilder
Sourcepub fn build(&self) -> Result<LoggingConfig, ConfigBuildError>
pub fn build(&self) -> Result<LoggingConfig, ConfigBuildError>
Try to construct a new LoggingConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.