pub async fn bind_proxy<R: Runtime>(
runtime: R,
tor_client: TorClient<R>,
listen: Listen,
protocols: ListenProtocols,
rpc_mgr: Option<Arc<RpcMgr>>,
) -> Result<StreamProxy<R>>Expand description
Launch a proxy to listen on a given set of ports.
Requires a runtime to use for launching tasks and handling
timeouts, and a tor_client to use in connecting over the Tor
network.
Returns the proxy, and a list of the ports that we have bound to.