fn classify_protocol_from_first_byte(byte: u8) -> Option<ProxyProtocols>Expand description
Look at the first byte of a proxy connection, and guess what protocol what protocol it is trying to speak.
fn classify_protocol_from_first_byte(byte: u8) -> Option<ProxyProtocols>Look at the first byte of a proxy connection, and guess what protocol what protocol it is trying to speak.