async fn transfer<S>(
request: Request<Incoming>,
tor_stream: DataStream,
) -> Result<()>Expand description
Recover the application stream from request, and launch tasks to transfer data between the application and
the tor_stream.
async fn transfer<S>(
request: Request<Incoming>,
tor_stream: DataStream,
) -> Result<()>Recover the application stream from request, and launch tasks to transfer data between the application and
the tor_stream.