type Body = String;Expand description
We use “String” as our body type, since we only return a body on error, in which case it already starts life as a formatted string.
(We could use () or Empty for our (200 OK) replies,
but empty strings are cheap enough that it isn’t worth it.)
Aliased Type
struct Body { /* private fields */ }