fn reconfigure(
config: &ConfigurationTree,
mgr_inner: &mut CfgMgrInner,
how: Reconfigure,
) -> Result<bool, ChangeConfigurationError>Expand description
Reload the configuration files, apply the runtime configuration, and reconfigure the client as much as we can.
Return true if we should be watching for configuration changes.