fn prompt(msg: &str) -> Result<bool>
Prompt the user to confirm by typing yes or no.
Loops until the user confirms or declines, returning true if they confirmed.
Returns an error if an IO error occurs.