fn read_ctor_keys<'a>(
entries: &[KeystoreEntryResult<KeystoreEntry<'a>>],
args: &CTorMigrateArgs,
) -> Result<HashMap<HsId, KeystoreEntry<'a>>>Expand description
Helper function for migrate_ctor_keys.
Parses and returns the client keys from the CTor keystore identified by --from CLI flag.
Detects if there is a clash (different keys for the same hidden service within
the CTor keystore).
Such a situation is invalid, as each service must have a unique key.
If a clash is found, an error is returned.
If no clashes are detected, returns a HashMap of keystore entries, keyed
by hidden service identifier.